%define ALD_Ver		1.2.1

Name:         tar

License:      GPL
Summary:      GNU tar saves/restore files to/from the archive
Group:        System/Tools
Version:      1.26
Release:      1

Requires: bzip2
Requires: xz
Requires: zlib

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		%{nil}

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target_  %{nil}
%define target %{_build}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}
%define _libexecdir %{_sbindir}

# ------------------- description ------------------------------------
%description
GNU tar saves many files together into a single tape or disk
archive, and can restore individual files from the archive.
# --------------------------------------
%package info
Summary:      Info for %{name}
Group:        Documentation
%description info
Info for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections"
LDFLAGS="-Wl,--gc-sections"
%endif

%if !%{_CROSS}
export FORCE_UNSAFE_CONFIGURE=1 
%endif

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--disable-silent-rules \
	--disable-rpath \
	--disable-nls \
	--without-included-regex \
	&>FConfigure_log.txt


make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

mv $RPM_BUILD_ROOT%{_bindir} $RPM_BUILD_ROOT
rm -r $RPM_BUILD_ROOT%{_infodir}/dir

cp AUTHORS COPYING README THANKS $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-info-$SE $DD/%{name}-info-$DE
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r bin usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}

%else  #mingw

%Files
/bin
%{_sbindir}
%{docdir}

%Files info
%{_infodir}

%endif #!mingw
